==> quarkus-core-deployment-1.0.1.Final-sources.jar: io/quarkus/deployment/pkg/NativeConfig$$accessor.java <==
package io.quarkus.deployment.pkg;
public final class NativeConfig$$accessor {
    private NativeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_additionalBuildArgs(Object __instance) {
        return ((NativeConfig)__instance).additionalBuildArgs;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalBuildArgs(Object __instance, Object additionalBuildArgs) {
        ((NativeConfig)__instance).additionalBuildArgs = (java.util.List<String>)additionalBuildArgs;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableHttpUrlHandler(Object __instance) {
        return ((NativeConfig)__instance).enableHttpUrlHandler;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableHttpUrlHandler(Object __instance, boolean enableHttpUrlHandler) {
        ((NativeConfig)__instance).enableHttpUrlHandler = enableHttpUrlHandler;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableHttpsUrlHandler(Object __instance) {
        return ((NativeConfig)__instance).enableHttpsUrlHandler;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableHttpsUrlHandler(Object __instance, boolean enableHttpsUrlHandler) {
        ((NativeConfig)__instance).enableHttpsUrlHandler = enableHttpsUrlHandler;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableAllSecurityServices(Object __instance) {
        return ((NativeConfig)__instance).enableAllSecurityServices;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableAllSecurityServices(Object __instance, boolean enableAllSecurityServices) {
        ((NativeConfig)__instance).enableAllSecurityServices = enableAllSecurityServices;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableJni(Object __instance) {
        return ((NativeConfig)__instance).enableJni;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableJni(Object __instance, boolean enableJni) {
        ((NativeConfig)__instance).enableJni = enableJni;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_addAllCharsets(Object __instance) {
        return ((NativeConfig)__instance).addAllCharsets;
    }
    @SuppressWarnings("unchecked")
    public static void set_addAllCharsets(Object __instance, boolean addAllCharsets) {
        ((NativeConfig)__instance).addAllCharsets = addAllCharsets;
    }
    @SuppressWarnings("unchecked")
    public static Object get_graalvmHome(Object __instance) {
        return ((NativeConfig)__instance).graalvmHome;
    }
    @SuppressWarnings("unchecked")
    public static void set_graalvmHome(Object __instance, Object graalvmHome) {
        ((NativeConfig)__instance).graalvmHome = (String)graalvmHome;
    }
    @SuppressWarnings("unchecked")
    public static Object get_javaHome(Object __instance) {
        return ((NativeConfig)__instance).javaHome;
    }
    @SuppressWarnings("unchecked")
    public static void set_javaHome(Object __instance, Object javaHome) {
        ((NativeConfig)__instance).javaHome = (java.io.File)javaHome;
    }
    @SuppressWarnings("unchecked")
    public static Object get_nativeImageXmx(Object __instance) {
        return ((NativeConfig)__instance).nativeImageXmx;
    }
    @SuppressWarnings("unchecked")
    public static void set_nativeImageXmx(Object __instance, Object nativeImageXmx) {
        ((NativeConfig)__instance).nativeImageXmx = (java.util.Optional<String>)nativeImageXmx;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_debugSymbols(Object __instance) {
        return ((NativeConfig)__instance).debugSymbols;
    }
    @SuppressWarnings("unchecked")
    public static void set_debugSymbols(Object __instance, boolean debugSymbols) {
        ((NativeConfig)__instance).debugSymbols = debugSymbols;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_debugBuildProcess(Object __instance) {
        return ((NativeConfig)__instance).debugBuildProcess;
    }
    @SuppressWarnings("unchecked")
    public static void set_debugBuildProcess(Object __instance, boolean debugBuildProcess) {
        ((NativeConfig)__instance).debugBuildProcess = debugBuildProcess;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_publishDebugBuildProcessPort(Object __instance) {
        return ((NativeConfig)__instance).publishDebugBuildProcessPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_publishDebugBuildProcessPort(Object __instance, boolean publishDebugBuildProcessPort) {
        ((NativeConfig)__instance).publishDebugBuildProcessPort = publishDebugBuildProcessPort;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_cleanupServer(Object __instance) {
        return ((NativeConfig)__instance).cleanupServer;
    }
    @SuppressWarnings("unchecked")
    public static void set_cleanupServer(Object __instance, boolean cleanupServer) {
        ((NativeConfig)__instance).cleanupServer = cleanupServer;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableIsolates(Object __instance) {
        return ((NativeConfig)__instance).enableIsolates;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableIsolates(Object __instance, boolean enableIsolates) {
        ((NativeConfig)__instance).enableIsolates = enableIsolates;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableFallbackImages(Object __instance) {
        return ((NativeConfig)__instance).enableFallbackImages;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableFallbackImages(Object __instance, boolean enableFallbackImages) {
        ((NativeConfig)__instance).enableFallbackImages = enableFallbackImages;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableServer(Object __instance) {
        return ((NativeConfig)__instance).enableServer;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableServer(Object __instance, boolean enableServer) {
        ((NativeConfig)__instance).enableServer = enableServer;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_autoServiceLoaderRegistration(Object __instance) {
        return ((NativeConfig)__instance).autoServiceLoaderRegistration;
    }
    @SuppressWarnings("unchecked")
    public static void set_autoServiceLoaderRegistration(Object __instance, boolean autoServiceLoaderRegistration) {
        ((NativeConfig)__instance).autoServiceLoaderRegistration = autoServiceLoaderRegistration;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_dumpProxies(Object __instance) {
        return ((NativeConfig)__instance).dumpProxies;
    }
    @SuppressWarnings("unchecked")
    public static void set_dumpProxies(Object __instance, boolean dumpProxies) {
        ((NativeConfig)__instance).dumpProxies = dumpProxies;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_containerBuild(Object __instance) {
        return ((NativeConfig)__instance).containerBuild;
    }
    @SuppressWarnings("unchecked")
    public static void set_containerBuild(Object __instance, boolean containerBuild) {
        ((NativeConfig)__instance).containerBuild = containerBuild;
    }
    @SuppressWarnings("unchecked")
    public static Object get_builderImage(Object __instance) {
        return ((NativeConfig)__instance).builderImage;
    }
    @SuppressWarnings("unchecked")
    public static void set_builderImage(Object __instance, Object builderImage) {
        ((NativeConfig)__instance).builderImage = (String)builderImage;
    }
    @SuppressWarnings("unchecked")
    public static Object get_containerRuntime(Object __instance) {
        return ((NativeConfig)__instance).containerRuntime;
    }
    @SuppressWarnings("unchecked")
    public static void set_containerRuntime(Object __instance, Object containerRuntime) {
        ((NativeConfig)__instance).containerRuntime = (String)containerRuntime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_containerRuntimeOptions(Object __instance) {
        return ((NativeConfig)__instance).containerRuntimeOptions;
    }
    @SuppressWarnings("unchecked")
    public static void set_containerRuntimeOptions(Object __instance, Object containerRuntimeOptions) {
        ((NativeConfig)__instance).containerRuntimeOptions = (java.util.List<String>)containerRuntimeOptions;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableVmInspection(Object __instance) {
        return ((NativeConfig)__instance).enableVmInspection;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableVmInspection(Object __instance, boolean enableVmInspection) {
        ((NativeConfig)__instance).enableVmInspection = enableVmInspection;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_fullStackTraces(Object __instance) {
        return ((NativeConfig)__instance).fullStackTraces;
    }
    @SuppressWarnings("unchecked")
    public static void set_fullStackTraces(Object __instance, boolean fullStackTraces) {
        ((NativeConfig)__instance).fullStackTraces = fullStackTraces;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableReports(Object __instance) {
        return ((NativeConfig)__instance).enableReports;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableReports(Object __instance, boolean enableReports) {
        ((NativeConfig)__instance).enableReports = enableReports;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_reportExceptionStackTraces(Object __instance) {
        return ((NativeConfig)__instance).reportExceptionStackTraces;
    }
    @SuppressWarnings("unchecked")
    public static void set_reportExceptionStackTraces(Object __instance, boolean reportExceptionStackTraces) {
        ((NativeConfig)__instance).reportExceptionStackTraces = reportExceptionStackTraces;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_reportErrorsAtRuntime(Object __instance) {
        return ((NativeConfig)__instance).reportErrorsAtRuntime;
    }
    @SuppressWarnings("unchecked")
    public static void set_reportErrorsAtRuntime(Object __instance, boolean reportErrorsAtRuntime) {
        ((NativeConfig)__instance).reportErrorsAtRuntime = reportErrorsAtRuntime;
    }
    public static Object construct() {
        return new NativeConfig();
    }
}

==> quarkus-core-deployment-1.4.1.Final-sources.jar: io/quarkus/deployment/pkg/NativeConfig$$accessor.java <==
package io.quarkus.deployment.pkg;
public final class NativeConfig$$accessor {
    private NativeConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_additionalBuildArgs(Object __instance) {
        return ((NativeConfig)__instance).additionalBuildArgs;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalBuildArgs(Object __instance, Object additionalBuildArgs) {
        ((NativeConfig)__instance).additionalBuildArgs = (java.util.Optional<java.util.List<String>>)additionalBuildArgs;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableHttpUrlHandler(Object __instance) {
        return ((NativeConfig)__instance).enableHttpUrlHandler;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableHttpUrlHandler(Object __instance, boolean enableHttpUrlHandler) {
        ((NativeConfig)__instance).enableHttpUrlHandler = enableHttpUrlHandler;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableHttpsUrlHandler(Object __instance) {
        return ((NativeConfig)__instance).enableHttpsUrlHandler;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableHttpsUrlHandler(Object __instance, boolean enableHttpsUrlHandler) {
        ((NativeConfig)__instance).enableHttpsUrlHandler = enableHttpsUrlHandler;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableAllSecurityServices(Object __instance) {
        return ((NativeConfig)__instance).enableAllSecurityServices;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableAllSecurityServices(Object __instance, boolean enableAllSecurityServices) {
        ((NativeConfig)__instance).enableAllSecurityServices = enableAllSecurityServices;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableJni(Object __instance) {
        return ((NativeConfig)__instance).enableJni;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableJni(Object __instance, boolean enableJni) {
        ((NativeConfig)__instance).enableJni = enableJni;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_addAllCharsets(Object __instance) {
        return ((NativeConfig)__instance).addAllCharsets;
    }
    @SuppressWarnings("unchecked")
    public static void set_addAllCharsets(Object __instance, boolean addAllCharsets) {
        ((NativeConfig)__instance).addAllCharsets = addAllCharsets;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_includeAllTimeZones(Object __instance) {
        return ((NativeConfig)__instance).includeAllTimeZones;
    }
    @SuppressWarnings("unchecked")
    public static void set_includeAllTimeZones(Object __instance, boolean includeAllTimeZones) {
        ((NativeConfig)__instance).includeAllTimeZones = includeAllTimeZones;
    }
    @SuppressWarnings("unchecked")
    public static Object get_graalvmHome(Object __instance) {
        return ((NativeConfig)__instance).graalvmHome;
    }
    @SuppressWarnings("unchecked")
    public static void set_graalvmHome(Object __instance, Object graalvmHome) {
        ((NativeConfig)__instance).graalvmHome = (java.util.Optional<String>)graalvmHome;
    }
    @SuppressWarnings("unchecked")
    public static Object get_javaHome(Object __instance) {
        return ((NativeConfig)__instance).javaHome;
    }
    @SuppressWarnings("unchecked")
    public static void set_javaHome(Object __instance, Object javaHome) {
        ((NativeConfig)__instance).javaHome = (java.io.File)javaHome;
    }
    @SuppressWarnings("unchecked")
    public static Object get_nativeImageXmx(Object __instance) {
        return ((NativeConfig)__instance).nativeImageXmx;
    }
    @SuppressWarnings("unchecked")
    public static void set_nativeImageXmx(Object __instance, Object nativeImageXmx) {
        ((NativeConfig)__instance).nativeImageXmx = (java.util.Optional<String>)nativeImageXmx;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_debugSymbols(Object __instance) {
        return ((NativeConfig)__instance).debugSymbols;
    }
    @SuppressWarnings("unchecked")
    public static void set_debugSymbols(Object __instance, boolean debugSymbols) {
        ((NativeConfig)__instance).debugSymbols = debugSymbols;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_debugBuildProcess(Object __instance) {
        return ((NativeConfig)__instance).debugBuildProcess;
    }
    @SuppressWarnings("unchecked")
    public static void set_debugBuildProcess(Object __instance, boolean debugBuildProcess) {
        ((NativeConfig)__instance).debugBuildProcess = debugBuildProcess;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_publishDebugBuildProcessPort(Object __instance) {
        return ((NativeConfig)__instance).publishDebugBuildProcessPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_publishDebugBuildProcessPort(Object __instance, boolean publishDebugBuildProcessPort) {
        ((NativeConfig)__instance).publishDebugBuildProcessPort = publishDebugBuildProcessPort;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_cleanupServer(Object __instance) {
        return ((NativeConfig)__instance).cleanupServer;
    }
    @SuppressWarnings("unchecked")
    public static void set_cleanupServer(Object __instance, boolean cleanupServer) {
        ((NativeConfig)__instance).cleanupServer = cleanupServer;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableIsolates(Object __instance) {
        return ((NativeConfig)__instance).enableIsolates;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableIsolates(Object __instance, boolean enableIsolates) {
        ((NativeConfig)__instance).enableIsolates = enableIsolates;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableFallbackImages(Object __instance) {
        return ((NativeConfig)__instance).enableFallbackImages;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableFallbackImages(Object __instance, boolean enableFallbackImages) {
        ((NativeConfig)__instance).enableFallbackImages = enableFallbackImages;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableServer(Object __instance) {
        return ((NativeConfig)__instance).enableServer;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableServer(Object __instance, boolean enableServer) {
        ((NativeConfig)__instance).enableServer = enableServer;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_autoServiceLoaderRegistration(Object __instance) {
        return ((NativeConfig)__instance).autoServiceLoaderRegistration;
    }
    @SuppressWarnings("unchecked")
    public static void set_autoServiceLoaderRegistration(Object __instance, boolean autoServiceLoaderRegistration) {
        ((NativeConfig)__instance).autoServiceLoaderRegistration = autoServiceLoaderRegistration;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_dumpProxies(Object __instance) {
        return ((NativeConfig)__instance).dumpProxies;
    }
    @SuppressWarnings("unchecked")
    public static void set_dumpProxies(Object __instance, boolean dumpProxies) {
        ((NativeConfig)__instance).dumpProxies = dumpProxies;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_containerBuild(Object __instance) {
        return ((NativeConfig)__instance).containerBuild;
    }
    @SuppressWarnings("unchecked")
    public static void set_containerBuild(Object __instance, boolean containerBuild) {
        ((NativeConfig)__instance).containerBuild = containerBuild;
    }
    @SuppressWarnings("unchecked")
    public static Object get_builderImage(Object __instance) {
        return ((NativeConfig)__instance).builderImage;
    }
    @SuppressWarnings("unchecked")
    public static void set_builderImage(Object __instance, Object builderImage) {
        ((NativeConfig)__instance).builderImage = (String)builderImage;
    }
    @SuppressWarnings("unchecked")
    public static Object get_containerRuntime(Object __instance) {
        return ((NativeConfig)__instance).containerRuntime;
    }
    @SuppressWarnings("unchecked")
    public static void set_containerRuntime(Object __instance, Object containerRuntime) {
        ((NativeConfig)__instance).containerRuntime = (java.util.Optional<String>)containerRuntime;
    }
    @SuppressWarnings("unchecked")
    public static Object get_containerRuntimeOptions(Object __instance) {
        return ((NativeConfig)__instance).containerRuntimeOptions;
    }
    @SuppressWarnings("unchecked")
    public static void set_containerRuntimeOptions(Object __instance, Object containerRuntimeOptions) {
        ((NativeConfig)__instance).containerRuntimeOptions = (java.util.Optional<java.util.List<String>>)containerRuntimeOptions;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableVmInspection(Object __instance) {
        return ((NativeConfig)__instance).enableVmInspection;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableVmInspection(Object __instance, boolean enableVmInspection) {
        ((NativeConfig)__instance).enableVmInspection = enableVmInspection;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_fullStackTraces(Object __instance) {
        return ((NativeConfig)__instance).fullStackTraces;
    }
    @SuppressWarnings("unchecked")
    public static void set_fullStackTraces(Object __instance, boolean fullStackTraces) {
        ((NativeConfig)__instance).fullStackTraces = fullStackTraces;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_enableReports(Object __instance) {
        return ((NativeConfig)__instance).enableReports;
    }
    @SuppressWarnings("unchecked")
    public static void set_enableReports(Object __instance, boolean enableReports) {
        ((NativeConfig)__instance).enableReports = enableReports;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_reportExceptionStackTraces(Object __instance) {
        return ((NativeConfig)__instance).reportExceptionStackTraces;
    }
    @SuppressWarnings("unchecked")
    public static void set_reportExceptionStackTraces(Object __instance, boolean reportExceptionStackTraces) {
        ((NativeConfig)__instance).reportExceptionStackTraces = reportExceptionStackTraces;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_reportErrorsAtRuntime(Object __instance) {
        return ((NativeConfig)__instance).reportErrorsAtRuntime;
    }
    @SuppressWarnings("unchecked")
    public static void set_reportErrorsAtRuntime(Object __instance, boolean reportErrorsAtRuntime) {
        ((NativeConfig)__instance).reportErrorsAtRuntime = reportErrorsAtRuntime;
    }
    public static Object construct() {
        return new NativeConfig();
    }
}
